pub type MonotonicMultilevelMap<'a, K, T> = Map<(K, u64), T>;
A multilevel Map where the suffix of the key monotonically increases.
This represents a common pattern where we want to store a data series by
some key, such as a series of position events per position. The u64 is
guaranteed to monotonically increase over time per K value.